@@ -1,4 +1,4 @@
-#!/usr/local/bin/perl -w
+#!/bin/perl
 
 # to load this file when the server starts, add this to httpd.conf:
 # PerlRequire /path/to/startup.pl
@@ -6,11 +6,15 @@
 # make sure we are in a sane environment.
 $ENV{MOD_PERL} or die "GATEWAY_INTERFACE not Perl!";
 
-use Apache::Registry;
 use Apache::forks;
-#use Apache::forks::shared;
-use strict;
+#Apache::forks->DEBUG(1);	#enable for apache error_log debug information
 
 #...other startup modules and items go here
 
+use Apache::Registry;
+use DBI();
+use DBD::Oracle();
+use lib '/etc/apache';
+use mycache;
+
 1;
